# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.15.10+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class CatalogV5(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'books': 'list[str]',
        'branch_or_tag_name': 'str',
        'contents_url': 'str',
        'full_name': 'str',
        'git_trees_url': 'str',
        'id': 'int',
        'ingredients': 'list[object]',
        'language': 'str',
        'metadata_api_contents_url': 'str',
        'metadata_json_url': 'str',
        'metadata_url': 'str',
        'metadata_version': 'str',
        'name': 'str',
        'owner': 'str',
        'release': 'Release',
        'released': 'datetime',
        'repo': 'Repository',
        'stage': 'str',
        'subject': 'str',
        'tarbar_url': 'str',
        'title': 'str',
        'url': 'str',
        'zipball_url': 'str'
    }

    attribute_map = {
        'books': 'books',
        'branch_or_tag_name': 'branch_or_tag_name',
        'contents_url': 'contents_url',
        'full_name': 'full_name',
        'git_trees_url': 'git_trees_url',
        'id': 'id',
        'ingredients': 'ingredients',
        'language': 'language',
        'metadata_api_contents_url': 'metadata_api_contents_url',
        'metadata_json_url': 'metadata_json_url',
        'metadata_url': 'metadata_url',
        'metadata_version': 'metadata_version',
        'name': 'name',
        'owner': 'owner',
        'release': 'release',
        'released': 'released',
        'repo': 'repo',
        'stage': 'stage',
        'subject': 'subject',
        'tarbar_url': 'tarbar_url',
        'title': 'title',
        'url': 'url',
        'zipball_url': 'zipball_url'
    }

    def __init__(self, books=None, branch_or_tag_name=None, contents_url=None, full_name=None, git_trees_url=None, id=None, ingredients=None, language=None, metadata_api_contents_url=None, metadata_json_url=None, metadata_url=None, metadata_version=None, name=None, owner=None, release=None, released=None, repo=None, stage=None, subject=None, tarbar_url=None, title=None, url=None, zipball_url=None, _configuration=None):  # noqa: E501
        """CatalogV5 - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._books = None
        self._branch_or_tag_name = None
        self._contents_url = None
        self._full_name = None
        self._git_trees_url = None
        self._id = None
        self._ingredients = None
        self._language = None
        self._metadata_api_contents_url = None
        self._metadata_json_url = None
        self._metadata_url = None
        self._metadata_version = None
        self._name = None
        self._owner = None
        self._release = None
        self._released = None
        self._repo = None
        self._stage = None
        self._subject = None
        self._tarbar_url = None
        self._title = None
        self._url = None
        self._zipball_url = None
        self.discriminator = None

        if books is not None:
            self.books = books
        if branch_or_tag_name is not None:
            self.branch_or_tag_name = branch_or_tag_name
        if contents_url is not None:
            self.contents_url = contents_url
        if full_name is not None:
            self.full_name = full_name
        if git_trees_url is not None:
            self.git_trees_url = git_trees_url
        if id is not None:
            self.id = id
        if ingredients is not None:
            self.ingredients = ingredients
        if language is not None:
            self.language = language
        if metadata_api_contents_url is not None:
            self.metadata_api_contents_url = metadata_api_contents_url
        if metadata_json_url is not None:
            self.metadata_json_url = metadata_json_url
        if metadata_url is not None:
            self.metadata_url = metadata_url
        if metadata_version is not None:
            self.metadata_version = metadata_version
        if name is not None:
            self.name = name
        if owner is not None:
            self.owner = owner
        if release is not None:
            self.release = release
        if released is not None:
            self.released = released
        if repo is not None:
            self.repo = repo
        if stage is not None:
            self.stage = stage
        if subject is not None:
            self.subject = subject
        if tarbar_url is not None:
            self.tarbar_url = tarbar_url
        if title is not None:
            self.title = title
        if url is not None:
            self.url = url
        if zipball_url is not None:
            self.zipball_url = zipball_url

    @property
    def books(self):
        """Gets the books of this CatalogV5.  # noqa: E501


        :return: The books of this CatalogV5.  # noqa: E501
        :rtype: list[str]
        """
        return self._books

    @books.setter
    def books(self, books):
        """Sets the books of this CatalogV5.


        :param books: The books of this CatalogV5.  # noqa: E501
        :type: list[str]
        """

        self._books = books

    @property
    def branch_or_tag_name(self):
        """Gets the branch_or_tag_name of this CatalogV5.  # noqa: E501


        :return: The branch_or_tag_name of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._branch_or_tag_name

    @branch_or_tag_name.setter
    def branch_or_tag_name(self, branch_or_tag_name):
        """Sets the branch_or_tag_name of this CatalogV5.


        :param branch_or_tag_name: The branch_or_tag_name of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._branch_or_tag_name = branch_or_tag_name

    @property
    def contents_url(self):
        """Gets the contents_url of this CatalogV5.  # noqa: E501


        :return: The contents_url of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._contents_url

    @contents_url.setter
    def contents_url(self, contents_url):
        """Sets the contents_url of this CatalogV5.


        :param contents_url: The contents_url of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._contents_url = contents_url

    @property
    def full_name(self):
        """Gets the full_name of this CatalogV5.  # noqa: E501


        :return: The full_name of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this CatalogV5.


        :param full_name: The full_name of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._full_name = full_name

    @property
    def git_trees_url(self):
        """Gets the git_trees_url of this CatalogV5.  # noqa: E501


        :return: The git_trees_url of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._git_trees_url

    @git_trees_url.setter
    def git_trees_url(self, git_trees_url):
        """Sets the git_trees_url of this CatalogV5.


        :param git_trees_url: The git_trees_url of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._git_trees_url = git_trees_url

    @property
    def id(self):
        """Gets the id of this CatalogV5.  # noqa: E501


        :return: The id of this CatalogV5.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CatalogV5.


        :param id: The id of this CatalogV5.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def ingredients(self):
        """Gets the ingredients of this CatalogV5.  # noqa: E501


        :return: The ingredients of this CatalogV5.  # noqa: E501
        :rtype: list[object]
        """
        return self._ingredients

    @ingredients.setter
    def ingredients(self, ingredients):
        """Sets the ingredients of this CatalogV5.


        :param ingredients: The ingredients of this CatalogV5.  # noqa: E501
        :type: list[object]
        """

        self._ingredients = ingredients

    @property
    def language(self):
        """Gets the language of this CatalogV5.  # noqa: E501


        :return: The language of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this CatalogV5.


        :param language: The language of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def metadata_api_contents_url(self):
        """Gets the metadata_api_contents_url of this CatalogV5.  # noqa: E501


        :return: The metadata_api_contents_url of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._metadata_api_contents_url

    @metadata_api_contents_url.setter
    def metadata_api_contents_url(self, metadata_api_contents_url):
        """Sets the metadata_api_contents_url of this CatalogV5.


        :param metadata_api_contents_url: The metadata_api_contents_url of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._metadata_api_contents_url = metadata_api_contents_url

    @property
    def metadata_json_url(self):
        """Gets the metadata_json_url of this CatalogV5.  # noqa: E501


        :return: The metadata_json_url of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._metadata_json_url

    @metadata_json_url.setter
    def metadata_json_url(self, metadata_json_url):
        """Sets the metadata_json_url of this CatalogV5.


        :param metadata_json_url: The metadata_json_url of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._metadata_json_url = metadata_json_url

    @property
    def metadata_url(self):
        """Gets the metadata_url of this CatalogV5.  # noqa: E501


        :return: The metadata_url of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._metadata_url

    @metadata_url.setter
    def metadata_url(self, metadata_url):
        """Sets the metadata_url of this CatalogV5.


        :param metadata_url: The metadata_url of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._metadata_url = metadata_url

    @property
    def metadata_version(self):
        """Gets the metadata_version of this CatalogV5.  # noqa: E501


        :return: The metadata_version of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._metadata_version

    @metadata_version.setter
    def metadata_version(self, metadata_version):
        """Sets the metadata_version of this CatalogV5.


        :param metadata_version: The metadata_version of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._metadata_version = metadata_version

    @property
    def name(self):
        """Gets the name of this CatalogV5.  # noqa: E501


        :return: The name of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CatalogV5.


        :param name: The name of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def owner(self):
        """Gets the owner of this CatalogV5.  # noqa: E501


        :return: The owner of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this CatalogV5.


        :param owner: The owner of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._owner = owner

    @property
    def release(self):
        """Gets the release of this CatalogV5.  # noqa: E501


        :return: The release of this CatalogV5.  # noqa: E501
        :rtype: Release
        """
        return self._release

    @release.setter
    def release(self, release):
        """Sets the release of this CatalogV5.


        :param release: The release of this CatalogV5.  # noqa: E501
        :type: Release
        """

        self._release = release

    @property
    def released(self):
        """Gets the released of this CatalogV5.  # noqa: E501


        :return: The released of this CatalogV5.  # noqa: E501
        :rtype: datetime
        """
        return self._released

    @released.setter
    def released(self, released):
        """Sets the released of this CatalogV5.


        :param released: The released of this CatalogV5.  # noqa: E501
        :type: datetime
        """

        self._released = released

    @property
    def repo(self):
        """Gets the repo of this CatalogV5.  # noqa: E501


        :return: The repo of this CatalogV5.  # noqa: E501
        :rtype: Repository
        """
        return self._repo

    @repo.setter
    def repo(self, repo):
        """Sets the repo of this CatalogV5.


        :param repo: The repo of this CatalogV5.  # noqa: E501
        :type: Repository
        """

        self._repo = repo

    @property
    def stage(self):
        """Gets the stage of this CatalogV5.  # noqa: E501


        :return: The stage of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._stage

    @stage.setter
    def stage(self, stage):
        """Sets the stage of this CatalogV5.


        :param stage: The stage of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._stage = stage

    @property
    def subject(self):
        """Gets the subject of this CatalogV5.  # noqa: E501


        :return: The subject of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this CatalogV5.


        :param subject: The subject of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def tarbar_url(self):
        """Gets the tarbar_url of this CatalogV5.  # noqa: E501


        :return: The tarbar_url of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._tarbar_url

    @tarbar_url.setter
    def tarbar_url(self, tarbar_url):
        """Sets the tarbar_url of this CatalogV5.


        :param tarbar_url: The tarbar_url of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._tarbar_url = tarbar_url

    @property
    def title(self):
        """Gets the title of this CatalogV5.  # noqa: E501


        :return: The title of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this CatalogV5.


        :param title: The title of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def url(self):
        """Gets the url of this CatalogV5.  # noqa: E501


        :return: The url of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this CatalogV5.


        :param url: The url of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def zipball_url(self):
        """Gets the zipball_url of this CatalogV5.  # noqa: E501


        :return: The zipball_url of this CatalogV5.  # noqa: E501
        :rtype: str
        """
        return self._zipball_url

    @zipball_url.setter
    def zipball_url(self, zipball_url):
        """Sets the zipball_url of this CatalogV5.


        :param zipball_url: The zipball_url of this CatalogV5.  # noqa: E501
        :type: str
        """

        self._zipball_url = zipball_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CatalogV5, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CatalogV5):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CatalogV5):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.15.10+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import dcs_catalog_client
from dcs_catalog_client.api.misc_api import MiscApi  # noqa: E501
from dcs_catalog_client.rest import ApiException


class TestMiscApi(unittest.TestCase):
    """MiscApi unit test stubs"""

    def setUp(self):
        self.api = dcs_catalog_client.api.misc_api.MiscApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_misc_list_catalog_version_endpoints(self):
        """Test case for misc_list_catalog_version_endpoints

        Catalog Next version endpoint list, including what version \"latest\" points to  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.15.10+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import dcs_catalog_client
from dcs_catalog_client.api.v5_api import V5Api  # noqa: E501
from dcs_catalog_client.rest import ApiException


class TestV5Api(unittest.TestCase):
    """V5Api unit test stubs"""

    def setUp(self):
        self.api = dcs_catalog_client.api.v5_api.V5Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_v5_get_catalog_entry(self):
        """Test case for v5_get_catalog_entry

        Catalog entry  # noqa: E501
        """
        pass

    def test_v5_get_metadata(self):
        """Test case for v5_get_metadata

        Catalog entry metadata (manifest.yaml in JSON format)  # noqa: E501
        """
        pass

    def test_v5_search(self):
        """Test case for v5_search

        Catalog search  # noqa: E501
        """
        pass

    def test_v5_search_owner(self):
        """Test case for v5_search_owner

        Catalog search by owner  # noqa: E501
        """
        pass

    def test_v5_search_repo(self):
        """Test case for v5_search_repo

        Catalog search by repo  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.15.10+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class CatalogStages(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'draft': 'CatalogStage',
        'latest': 'CatalogStage',
        'preprod': 'CatalogStage',
        'prod': 'CatalogStage'
    }

    attribute_map = {
        'draft': 'draft',
        'latest': 'latest',
        'preprod': 'preprod',
        'prod': 'prod'
    }

    def __init__(self, draft=None, latest=None, preprod=None, prod=None, _configuration=None):  # noqa: E501
        """CatalogStages - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._draft = None
        self._latest = None
        self._preprod = None
        self._prod = None
        self.discriminator = None

        if draft is not None:
            self.draft = draft
        if latest is not None:
            self.latest = latest
        if preprod is not None:
            self.preprod = preprod
        if prod is not None:
            self.prod = prod

    @property
    def draft(self):
        """Gets the draft of this CatalogStages.  # noqa: E501


        :return: The draft of this CatalogStages.  # noqa: E501
        :rtype: CatalogStage
        """
        return self._draft

    @draft.setter
    def draft(self, draft):
        """Sets the draft of this CatalogStages.


        :param draft: The draft of this CatalogStages.  # noqa: E501
        :type: CatalogStage
        """

        self._draft = draft

    @property
    def latest(self):
        """Gets the latest of this CatalogStages.  # noqa: E501


        :return: The latest of this CatalogStages.  # noqa: E501
        :rtype: CatalogStage
        """
        return self._latest

    @latest.setter
    def latest(self, latest):
        """Sets the latest of this CatalogStages.


        :param latest: The latest of this CatalogStages.  # noqa: E501
        :type: CatalogStage
        """

        self._latest = latest

    @property
    def preprod(self):
        """Gets the preprod of this CatalogStages.  # noqa: E501


        :return: The preprod of this CatalogStages.  # noqa: E501
        :rtype: CatalogStage
        """
        return self._preprod

    @preprod.setter
    def preprod(self, preprod):
        """Sets the preprod of this CatalogStages.


        :param preprod: The preprod of this CatalogStages.  # noqa: E501
        :type: CatalogStage
        """

        self._preprod = preprod

    @property
    def prod(self):
        """Gets the prod of this CatalogStages.  # noqa: E501


        :return: The prod of this CatalogStages.  # noqa: E501
        :rtype: CatalogStage
        """
        return self._prod

    @prod.setter
    def prod(self, prod):
        """Sets the prod of this CatalogStages.


        :param prod: The prod of this CatalogStages.  # noqa: E501
        :type: CatalogStage
        """

        self._prod = prod

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CatalogStages, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CatalogStages):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CatalogStages):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.15.10+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class ExternalTracker(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'external_tracker_format': 'str',
        'external_tracker_style': 'str',
        'external_tracker_url': 'str'
    }

    attribute_map = {
        'external_tracker_format': 'external_tracker_format',
        'external_tracker_style': 'external_tracker_style',
        'external_tracker_url': 'external_tracker_url'
    }

    def __init__(self, external_tracker_format=None, external_tracker_style=None, external_tracker_url=None, _configuration=None):  # noqa: E501
        """ExternalTracker - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._external_tracker_format = None
        self._external_tracker_style = None
        self._external_tracker_url = None
        self.discriminator = None

        if external_tracker_format is not None:
            self.external_tracker_format = external_tracker_format
        if external_tracker_style is not None:
            self.external_tracker_style = external_tracker_style
        if external_tracker_url is not None:
            self.external_tracker_url = external_tracker_url

    @property
    def external_tracker_format(self):
        """Gets the external_tracker_format of this ExternalTracker.  # noqa: E501

        External Issue Tracker URL Format. Use the placeholders {user}, {repo} and {index} for the username, repository name and issue index.  # noqa: E501

        :return: The external_tracker_format of this ExternalTracker.  # noqa: E501
        :rtype: str
        """
        return self._external_tracker_format

    @external_tracker_format.setter
    def external_tracker_format(self, external_tracker_format):
        """Sets the external_tracker_format of this ExternalTracker.

        External Issue Tracker URL Format. Use the placeholders {user}, {repo} and {index} for the username, repository name and issue index.  # noqa: E501

        :param external_tracker_format: The external_tracker_format of this ExternalTracker.  # noqa: E501
        :type: str
        """

        self._external_tracker_format = external_tracker_format

    @property
    def external_tracker_style(self):
        """Gets the external_tracker_style of this ExternalTracker.  # noqa: E501

        External Issue Tracker Number Format, either `numeric` or `alphanumeric`  # noqa: E501

        :return: The external_tracker_style of this ExternalTracker.  # noqa: E501
        :rtype: str
        """
        return self._external_tracker_style

    @external_tracker_style.setter
    def external_tracker_style(self, external_tracker_style):
        """Sets the external_tracker_style of this ExternalTracker.

        External Issue Tracker Number Format, either `numeric` or `alphanumeric`  # noqa: E501

        :param external_tracker_style: The external_tracker_style of this ExternalTracker.  # noqa: E501
        :type: str
        """

        self._external_tracker_style = external_tracker_style

    @property
    def external_tracker_url(self):
        """Gets the external_tracker_url of this ExternalTracker.  # noqa: E501

        URL of external issue tracker.  # noqa: E501

        :return: The external_tracker_url of this ExternalTracker.  # noqa: E501
        :rtype: str
        """
        return self._external_tracker_url

    @external_tracker_url.setter
    def external_tracker_url(self, external_tracker_url):
        """Sets the external_tracker_url of this ExternalTracker.

        URL of external issue tracker.  # noqa: E501

        :param external_tracker_url: The external_tracker_url of this ExternalTracker.  # noqa: E501
        :type: str
        """

        self._external_tracker_url = external_tracker_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExternalTracker, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExternalTracker):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExternalTracker):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.15.10+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class Repository(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allow_merge_commits': 'bool',
        'allow_rebase': 'bool',
        'allow_rebase_explicit': 'bool',
        'allow_squash_merge': 'bool',
        'archived': 'bool',
        'avatar_url': 'str',
        'books': 'list[str]',
        'catalog': 'CatalogStages',
        'checking_level': 'str',
        'clone_url': 'str',
        'created_at': 'datetime',
        'default_branch': 'str',
        'default_merge_style': 'str',
        'description': 'str',
        'empty': 'bool',
        'external_tracker': 'ExternalTracker',
        'external_wiki': 'ExternalWiki',
        'fork': 'bool',
        'forks_count': 'int',
        'full_name': 'str',
        'has_issues': 'bool',
        'has_projects': 'bool',
        'has_pull_requests': 'bool',
        'has_wiki': 'bool',
        'html_url': 'str',
        'id': 'int',
        'ignore_whitespace_conflicts': 'bool',
        'internal': 'bool',
        'internal_tracker': 'InternalTracker',
        'language': 'str',
        'mirror': 'bool',
        'mirror_interval': 'str',
        'name': 'str',
        'open_issues_count': 'int',
        'open_pr_counter': 'int',
        'original_url': 'str',
        'owner': 'User',
        'parent': 'Repository',
        'permissions': 'Permission',
        'private': 'bool',
        'release_counter': 'int',
        'size': 'int',
        'ssh_url': 'str',
        'stars_count': 'int',
        'subject': 'str',
        'template': 'bool',
        'title': 'str',
        'updated_at': 'datetime',
        'watchers_count': 'int',
        'website': 'str'
    }

    attribute_map = {
        'allow_merge_commits': 'allow_merge_commits',
        'allow_rebase': 'allow_rebase',
        'allow_rebase_explicit': 'allow_rebase_explicit',
        'allow_squash_merge': 'allow_squash_merge',
        'archived': 'archived',
        'avatar_url': 'avatar_url',
        'books': 'books',
        'catalog': 'catalog',
        'checking_level': 'checking_level',
        'clone_url': 'clone_url',
        'created_at': 'created_at',
        'default_branch': 'default_branch',
        'default_merge_style': 'default_merge_style',
        'description': 'description',
        'empty': 'empty',
        'external_tracker': 'external_tracker',
        'external_wiki': 'external_wiki',
        'fork': 'fork',
        'forks_count': 'forks_count',
        'full_name': 'full_name',
        'has_issues': 'has_issues',
        'has_projects': 'has_projects',
        'has_pull_requests': 'has_pull_requests',
        'has_wiki': 'has_wiki',
        'html_url': 'html_url',
        'id': 'id',
        'ignore_whitespace_conflicts': 'ignore_whitespace_conflicts',
        'internal': 'internal',
        'internal_tracker': 'internal_tracker',
        'language': 'language',
        'mirror': 'mirror',
        'mirror_interval': 'mirror_interval',
        'name': 'name',
        'open_issues_count': 'open_issues_count',
        'open_pr_counter': 'open_pr_counter',
        'original_url': 'original_url',
        'owner': 'owner',
        'parent': 'parent',
        'permissions': 'permissions',
        'private': 'private',
        'release_counter': 'release_counter',
        'size': 'size',
        'ssh_url': 'ssh_url',
        'stars_count': 'stars_count',
        'subject': 'subject',
        'template': 'template',
        'title': 'title',
        'updated_at': 'updated_at',
        'watchers_count': 'watchers_count',
        'website': 'website'
    }

    def __init__(self, allow_merge_commits=None, allow_rebase=None, allow_rebase_explicit=None, allow_squash_merge=None, archived=None, avatar_url=None, books=None, catalog=None, checking_level=None, clone_url=None, created_at=None, default_branch=None, default_merge_style=None, description=None, empty=None, external_tracker=None, external_wiki=None, fork=None, forks_count=None, full_name=None, has_issues=None, has_projects=None, has_pull_requests=None, has_wiki=None, html_url=None, id=None, ignore_whitespace_conflicts=None, internal=None, internal_tracker=None, language=None, mirror=None, mirror_interval=None, name=None, open_issues_count=None, open_pr_counter=None, original_url=None, owner=None, parent=None, permissions=None, private=None, release_counter=None, size=None, ssh_url=None, stars_count=None, subject=None, template=None, title=None, updated_at=None, watchers_count=None, website=None, _configuration=None):  # noqa: E501
        """Repository - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._allow_merge_commits = None
        self._allow_rebase = None
        self._allow_rebase_explicit = None
        self._allow_squash_merge = None
        self._archived = None
        self._avatar_url = None
        self._books = None
        self._catalog = None
        self._checking_level = None
        self._clone_url = None
        self._created_at = None
        self._default_branch = None
        self._default_merge_style = None
        self._description = None
        self._empty = None
        self._external_tracker = None
        self._external_wiki = None
        self._fork = None
        self._forks_count = None
        self._full_name = None
        self._has_issues = None
        self._has_projects = None
        self._has_pull_requests = None
        self._has_wiki = None
        self._html_url = None
        self._id = None
        self._ignore_whitespace_conflicts = None
        self._internal = None
        self._internal_tracker = None
        self._language = None
        self._mirror = None
        self._mirror_interval = None
        self._name = None
        self._open_issues_count = None
        self._open_pr_counter = None
        self._original_url = None
        self._owner = None
        self._parent = None
        self._permissions = None
        self._private = None
        self._release_counter = None
        self._size = None
        self._ssh_url = None
        self._stars_count = None
        self._subject = None
        self._template = None
        self._title = None
        self._updated_at = None
        self._watchers_count = None
        self._website = None
        self.discriminator = None

        if allow_merge_commits is not None:
            self.allow_merge_commits = allow_merge_commits
        if allow_rebase is not None:
            self.allow_rebase = allow_rebase
        if allow_rebase_explicit is not None:
            self.allow_rebase_explicit = allow_rebase_explicit
        if allow_squash_merge is not None:
            self.allow_squash_merge = allow_squash_merge
        if archived is not None:
            self.archived = archived
        if avatar_url is not None:
            self.avatar_url = avatar_url
        if books is not None:
            self.books = books
        if catalog is not None:
            self.catalog = catalog
        if checking_level is not None:
            self.checking_level = checking_level
        if clone_url is not None:
            self.clone_url = clone_url
        if created_at is not None:
            self.created_at = created_at
        if default_branch is not None:
            self.default_branch = default_branch
        if default_merge_style is not None:
            self.default_merge_style = default_merge_style
        if description is not None:
            self.description = description
        if empty is not None:
            self.empty = empty
        if external_tracker is not None:
            self.external_tracker = external_tracker
        if external_wiki is not None:
            self.external_wiki = external_wiki
        if fork is not None:
            self.fork = fork
        if forks_count is not None:
            self.forks_count = forks_count
        if full_name is not None:
            self.full_name = full_name
        if has_issues is not None:
            self.has_issues = has_issues
        if has_projects is not None:
            self.has_projects = has_projects
        if has_pull_requests is not None:
            self.has_pull_requests = has_pull_requests
        if has_wiki is not None:
            self.has_wiki = has_wiki
        if html_url is not None:
            self.html_url = html_url
        if id is not None:
            self.id = id
        if ignore_whitespace_conflicts is not None:
            self.ignore_whitespace_conflicts = ignore_whitespace_conflicts
        if internal is not None:
            self.internal = internal
        if internal_tracker is not None:
            self.internal_tracker = internal_tracker
        if language is not None:
            self.language = language
        if mirror is not None:
            self.mirror = mirror
        if mirror_interval is not None:
            self.mirror_interval = mirror_interval
        if name is not None:
            self.name = name
        if open_issues_count is not None:
            self.open_issues_count = open_issues_count
        if open_pr_counter is not None:
            self.open_pr_counter = open_pr_counter
        if original_url is not None:
            self.original_url = original_url
        if owner is not None:
            self.owner = owner
        if parent is not None:
            self.parent = parent
        if permissions is not None:
            self.permissions = permissions
        if private is not None:
            self.private = private
        if release_counter is not None:
            self.release_counter = release_counter
        if size is not None:
            self.size = size
        if ssh_url is not None:
            self.ssh_url = ssh_url
        if stars_count is not None:
            self.stars_count = stars_count
        if subject is not None:
            self.subject = subject
        if template is not None:
            self.template = template
        if title is not None:
            self.title = title
        if updated_at is not None:
            self.updated_at = updated_at
        if watchers_count is not None:
            self.watchers_count = watchers_count
        if website is not None:
            self.website = website

    @property
    def allow_merge_commits(self):
        """Gets the allow_merge_commits of this Repository.  # noqa: E501


        :return: The allow_merge_commits of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._allow_merge_commits

    @allow_merge_commits.setter
    def allow_merge_commits(self, allow_merge_commits):
        """Sets the allow_merge_commits of this Repository.


        :param allow_merge_commits: The allow_merge_commits of this Repository.  # noqa: E501
        :type: bool
        """

        self._allow_merge_commits = allow_merge_commits

    @property
    def allow_rebase(self):
        """Gets the allow_rebase of this Repository.  # noqa: E501


        :return: The allow_rebase of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._allow_rebase

    @allow_rebase.setter
    def allow_rebase(self, allow_rebase):
        """Sets the allow_rebase of this Repository.


        :param allow_rebase: The allow_rebase of this Repository.  # noqa: E501
        :type: bool
        """

        self._allow_rebase = allow_rebase

    @property
    def allow_rebase_explicit(self):
        """Gets the allow_rebase_explicit of this Repository.  # noqa: E501


        :return: The allow_rebase_explicit of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._allow_rebase_explicit

    @allow_rebase_explicit.setter
    def allow_rebase_explicit(self, allow_rebase_explicit):
        """Sets the allow_rebase_explicit of this Repository.


        :param allow_rebase_explicit: The allow_rebase_explicit of this Repository.  # noqa: E501
        :type: bool
        """

        self._allow_rebase_explicit = allow_rebase_explicit

    @property
    def allow_squash_merge(self):
        """Gets the allow_squash_merge of this Repository.  # noqa: E501


        :return: The allow_squash_merge of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._allow_squash_merge

    @allow_squash_merge.setter
    def allow_squash_merge(self, allow_squash_merge):
        """Sets the allow_squash_merge of this Repository.


        :param allow_squash_merge: The allow_squash_merge of this Repository.  # noqa: E501
        :type: bool
        """

        self._allow_squash_merge = allow_squash_merge

    @property
    def archived(self):
        """Gets the archived of this Repository.  # noqa: E501


        :return: The archived of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this Repository.


        :param archived: The archived of this Repository.  # noqa: E501
        :type: bool
        """

        self._archived = archived

    @property
    def avatar_url(self):
        """Gets the avatar_url of this Repository.  # noqa: E501


        :return: The avatar_url of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._avatar_url

    @avatar_url.setter
    def avatar_url(self, avatar_url):
        """Sets the avatar_url of this Repository.


        :param avatar_url: The avatar_url of this Repository.  # noqa: E501
        :type: str
        """

        self._avatar_url = avatar_url

    @property
    def books(self):
        """Gets the books of this Repository.  # noqa: E501


        :return: The books of this Repository.  # noqa: E501
        :rtype: list[str]
        """
        return self._books

    @books.setter
    def books(self, books):
        """Sets the books of this Repository.


        :param books: The books of this Repository.  # noqa: E501
        :type: list[str]
        """

        self._books = books

    @property
    def catalog(self):
        """Gets the catalog of this Repository.  # noqa: E501


        :return: The catalog of this Repository.  # noqa: E501
        :rtype: CatalogStages
        """
        return self._catalog

    @catalog.setter
    def catalog(self, catalog):
        """Sets the catalog of this Repository.


        :param catalog: The catalog of this Repository.  # noqa: E501
        :type: CatalogStages
        """

        self._catalog = catalog

    @property
    def checking_level(self):
        """Gets the checking_level of this Repository.  # noqa: E501


        :return: The checking_level of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._checking_level

    @checking_level.setter
    def checking_level(self, checking_level):
        """Sets the checking_level of this Repository.


        :param checking_level: The checking_level of this Repository.  # noqa: E501
        :type: str
        """

        self._checking_level = checking_level

    @property
    def clone_url(self):
        """Gets the clone_url of this Repository.  # noqa: E501


        :return: The clone_url of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._clone_url

    @clone_url.setter
    def clone_url(self, clone_url):
        """Sets the clone_url of this Repository.


        :param clone_url: The clone_url of this Repository.  # noqa: E501
        :type: str
        """

        self._clone_url = clone_url

    @property
    def created_at(self):
        """Gets the created_at of this Repository.  # noqa: E501


        :return: The created_at of this Repository.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Repository.


        :param created_at: The created_at of this Repository.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def default_branch(self):
        """Gets the default_branch of this Repository.  # noqa: E501


        :return: The default_branch of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._default_branch

    @default_branch.setter
    def default_branch(self, default_branch):
        """Sets the default_branch of this Repository.


        :param default_branch: The default_branch of this Repository.  # noqa: E501
        :type: str
        """

        self._default_branch = default_branch

    @property
    def default_merge_style(self):
        """Gets the default_merge_style of this Repository.  # noqa: E501


        :return: The default_merge_style of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._default_merge_style

    @default_merge_style.setter
    def default_merge_style(self, default_merge_style):
        """Sets the default_merge_style of this Repository.


        :param default_merge_style: The default_merge_style of this Repository.  # noqa: E501
        :type: str
        """

        self._default_merge_style = default_merge_style

    @property
    def description(self):
        """Gets the description of this Repository.  # noqa: E501


        :return: The description of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Repository.


        :param description: The description of this Repository.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def empty(self):
        """Gets the empty of this Repository.  # noqa: E501


        :return: The empty of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._empty

    @empty.setter
    def empty(self, empty):
        """Sets the empty of this Repository.


        :param empty: The empty of this Repository.  # noqa: E501
        :type: bool
        """

        self._empty = empty

    @property
    def external_tracker(self):
        """Gets the external_tracker of this Repository.  # noqa: E501


        :return: The external_tracker of this Repository.  # noqa: E501
        :rtype: ExternalTracker
        """
        return self._external_tracker

    @external_tracker.setter
    def external_tracker(self, external_tracker):
        """Sets the external_tracker of this Repository.


        :param external_tracker: The external_tracker of this Repository.  # noqa: E501
        :type: ExternalTracker
        """

        self._external_tracker = external_tracker

    @property
    def external_wiki(self):
        """Gets the external_wiki of this Repository.  # noqa: E501


        :return: The external_wiki of this Repository.  # noqa: E501
        :rtype: ExternalWiki
        """
        return self._external_wiki

    @external_wiki.setter
    def external_wiki(self, external_wiki):
        """Sets the external_wiki of this Repository.


        :param external_wiki: The external_wiki of this Repository.  # noqa: E501
        :type: ExternalWiki
        """

        self._external_wiki = external_wiki

    @property
    def fork(self):
        """Gets the fork of this Repository.  # noqa: E501


        :return: The fork of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._fork

    @fork.setter
    def fork(self, fork):
        """Sets the fork of this Repository.


        :param fork: The fork of this Repository.  # noqa: E501
        :type: bool
        """

        self._fork = fork

    @property
    def forks_count(self):
        """Gets the forks_count of this Repository.  # noqa: E501


        :return: The forks_count of this Repository.  # noqa: E501
        :rtype: int
        """
        return self._forks_count

    @forks_count.setter
    def forks_count(self, forks_count):
        """Sets the forks_count of this Repository.


        :param forks_count: The forks_count of this Repository.  # noqa: E501
        :type: int
        """

        self._forks_count = forks_count

    @property
    def full_name(self):
        """Gets the full_name of this Repository.  # noqa: E501


        :return: The full_name of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this Repository.


        :param full_name: The full_name of this Repository.  # noqa: E501
        :type: str
        """

        self._full_name = full_name

    @property
    def has_issues(self):
        """Gets the has_issues of this Repository.  # noqa: E501


        :return: The has_issues of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._has_issues

    @has_issues.setter
    def has_issues(self, has_issues):
        """Sets the has_issues of this Repository.


        :param has_issues: The has_issues of this Repository.  # noqa: E501
        :type: bool
        """

        self._has_issues = has_issues

    @property
    def has_projects(self):
        """Gets the has_projects of this Repository.  # noqa: E501


        :return: The has_projects of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._has_projects

    @has_projects.setter
    def has_projects(self, has_projects):
        """Sets the has_projects of this Repository.


        :param has_projects: The has_projects of this Repository.  # noqa: E501
        :type: bool
        """

        self._has_projects = has_projects

    @property
    def has_pull_requests(self):
        """Gets the has_pull_requests of this Repository.  # noqa: E501


        :return: The has_pull_requests of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._has_pull_requests

    @has_pull_requests.setter
    def has_pull_requests(self, has_pull_requests):
        """Sets the has_pull_requests of this Repository.


        :param has_pull_requests: The has_pull_requests of this Repository.  # noqa: E501
        :type: bool
        """

        self._has_pull_requests = has_pull_requests

    @property
    def has_wiki(self):
        """Gets the has_wiki of this Repository.  # noqa: E501


        :return: The has_wiki of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._has_wiki

    @has_wiki.setter
    def has_wiki(self, has_wiki):
        """Sets the has_wiki of this Repository.


        :param has_wiki: The has_wiki of this Repository.  # noqa: E501
        :type: bool
        """

        self._has_wiki = has_wiki

    @property
    def html_url(self):
        """Gets the html_url of this Repository.  # noqa: E501


        :return: The html_url of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._html_url

    @html_url.setter
    def html_url(self, html_url):
        """Sets the html_url of this Repository.


        :param html_url: The html_url of this Repository.  # noqa: E501
        :type: str
        """

        self._html_url = html_url

    @property
    def id(self):
        """Gets the id of this Repository.  # noqa: E501


        :return: The id of this Repository.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Repository.


        :param id: The id of this Repository.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def ignore_whitespace_conflicts(self):
        """Gets the ignore_whitespace_conflicts of this Repository.  # noqa: E501


        :return: The ignore_whitespace_conflicts of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_whitespace_conflicts

    @ignore_whitespace_conflicts.setter
    def ignore_whitespace_conflicts(self, ignore_whitespace_conflicts):
        """Sets the ignore_whitespace_conflicts of this Repository.


        :param ignore_whitespace_conflicts: The ignore_whitespace_conflicts of this Repository.  # noqa: E501
        :type: bool
        """

        self._ignore_whitespace_conflicts = ignore_whitespace_conflicts

    @property
    def internal(self):
        """Gets the internal of this Repository.  # noqa: E501


        :return: The internal of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._internal

    @internal.setter
    def internal(self, internal):
        """Sets the internal of this Repository.


        :param internal: The internal of this Repository.  # noqa: E501
        :type: bool
        """

        self._internal = internal

    @property
    def internal_tracker(self):
        """Gets the internal_tracker of this Repository.  # noqa: E501


        :return: The internal_tracker of this Repository.  # noqa: E501
        :rtype: InternalTracker
        """
        return self._internal_tracker

    @internal_tracker.setter
    def internal_tracker(self, internal_tracker):
        """Sets the internal_tracker of this Repository.


        :param internal_tracker: The internal_tracker of this Repository.  # noqa: E501
        :type: InternalTracker
        """

        self._internal_tracker = internal_tracker

    @property
    def language(self):
        """Gets the language of this Repository.  # noqa: E501


        :return: The language of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this Repository.


        :param language: The language of this Repository.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def mirror(self):
        """Gets the mirror of this Repository.  # noqa: E501


        :return: The mirror of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._mirror

    @mirror.setter
    def mirror(self, mirror):
        """Sets the mirror of this Repository.


        :param mirror: The mirror of this Repository.  # noqa: E501
        :type: bool
        """

        self._mirror = mirror

    @property
    def mirror_interval(self):
        """Gets the mirror_interval of this Repository.  # noqa: E501


        :return: The mirror_interval of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._mirror_interval

    @mirror_interval.setter
    def mirror_interval(self, mirror_interval):
        """Sets the mirror_interval of this Repository.


        :param mirror_interval: The mirror_interval of this Repository.  # noqa: E501
        :type: str
        """

        self._mirror_interval = mirror_interval

    @property
    def name(self):
        """Gets the name of this Repository.  # noqa: E501


        :return: The name of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Repository.


        :param name: The name of this Repository.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def open_issues_count(self):
        """Gets the open_issues_count of this Repository.  # noqa: E501


        :return: The open_issues_count of this Repository.  # noqa: E501
        :rtype: int
        """
        return self._open_issues_count

    @open_issues_count.setter
    def open_issues_count(self, open_issues_count):
        """Sets the open_issues_count of this Repository.


        :param open_issues_count: The open_issues_count of this Repository.  # noqa: E501
        :type: int
        """

        self._open_issues_count = open_issues_count

    @property
    def open_pr_counter(self):
        """Gets the open_pr_counter of this Repository.  # noqa: E501


        :return: The open_pr_counter of this Repository.  # noqa: E501
        :rtype: int
        """
        return self._open_pr_counter

    @open_pr_counter.setter
    def open_pr_counter(self, open_pr_counter):
        """Sets the open_pr_counter of this Repository.


        :param open_pr_counter: The open_pr_counter of this Repository.  # noqa: E501
        :type: int
        """

        self._open_pr_counter = open_pr_counter

    @property
    def original_url(self):
        """Gets the original_url of this Repository.  # noqa: E501


        :return: The original_url of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._original_url

    @original_url.setter
    def original_url(self, original_url):
        """Sets the original_url of this Repository.


        :param original_url: The original_url of this Repository.  # noqa: E501
        :type: str
        """

        self._original_url = original_url

    @property
    def owner(self):
        """Gets the owner of this Repository.  # noqa: E501


        :return: The owner of this Repository.  # noqa: E501
        :rtype: User
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this Repository.


        :param owner: The owner of this Repository.  # noqa: E501
        :type: User
        """

        self._owner = owner

    @property
    def parent(self):
        """Gets the parent of this Repository.  # noqa: E501


        :return: The parent of this Repository.  # noqa: E501
        :rtype: Repository
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this Repository.


        :param parent: The parent of this Repository.  # noqa: E501
        :type: Repository
        """

        self._parent = parent

    @property
    def permissions(self):
        """Gets the permissions of this Repository.  # noqa: E501


        :return: The permissions of this Repository.  # noqa: E501
        :rtype: Permission
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this Repository.


        :param permissions: The permissions of this Repository.  # noqa: E501
        :type: Permission
        """

        self._permissions = permissions

    @property
    def private(self):
        """Gets the private of this Repository.  # noqa: E501


        :return: The private of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._private

    @private.setter
    def private(self, private):
        """Sets the private of this Repository.


        :param private: The private of this Repository.  # noqa: E501
        :type: bool
        """

        self._private = private

    @property
    def release_counter(self):
        """Gets the release_counter of this Repository.  # noqa: E501


        :return: The release_counter of this Repository.  # noqa: E501
        :rtype: int
        """
        return self._release_counter

    @release_counter.setter
    def release_counter(self, release_counter):
        """Sets the release_counter of this Repository.


        :param release_counter: The release_counter of this Repository.  # noqa: E501
        :type: int
        """

        self._release_counter = release_counter

    @property
    def size(self):
        """Gets the size of this Repository.  # noqa: E501


        :return: The size of this Repository.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Repository.


        :param size: The size of this Repository.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def ssh_url(self):
        """Gets the ssh_url of this Repository.  # noqa: E501


        :return: The ssh_url of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._ssh_url

    @ssh_url.setter
    def ssh_url(self, ssh_url):
        """Sets the ssh_url of this Repository.


        :param ssh_url: The ssh_url of this Repository.  # noqa: E501
        :type: str
        """

        self._ssh_url = ssh_url

    @property
    def stars_count(self):
        """Gets the stars_count of this Repository.  # noqa: E501


        :return: The stars_count of this Repository.  # noqa: E501
        :rtype: int
        """
        return self._stars_count

    @stars_count.setter
    def stars_count(self, stars_count):
        """Sets the stars_count of this Repository.


        :param stars_count: The stars_count of this Repository.  # noqa: E501
        :type: int
        """

        self._stars_count = stars_count

    @property
    def subject(self):
        """Gets the subject of this Repository.  # noqa: E501


        :return: The subject of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this Repository.


        :param subject: The subject of this Repository.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def template(self):
        """Gets the template of this Repository.  # noqa: E501


        :return: The template of this Repository.  # noqa: E501
        :rtype: bool
        """
        return self._template

    @template.setter
    def template(self, template):
        """Sets the template of this Repository.


        :param template: The template of this Repository.  # noqa: E501
        :type: bool
        """

        self._template = template

    @property
    def title(self):
        """Gets the title of this Repository.  # noqa: E501


        :return: The title of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Repository.


        :param title: The title of this Repository.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def updated_at(self):
        """Gets the updated_at of this Repository.  # noqa: E501


        :return: The updated_at of this Repository.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Repository.


        :param updated_at: The updated_at of this Repository.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def watchers_count(self):
        """Gets the watchers_count of this Repository.  # noqa: E501


        :return: The watchers_count of this Repository.  # noqa: E501
        :rtype: int
        """
        return self._watchers_count

    @watchers_count.setter
    def watchers_count(self, watchers_count):
        """Sets the watchers_count of this Repository.


        :param watchers_count: The watchers_count of this Repository.  # noqa: E501
        :type: int
        """

        self._watchers_count = watchers_count

    @property
    def website(self):
        """Gets the website of this Repository.  # noqa: E501


        :return: The website of this Repository.  # noqa: E501
        :rtype: str
        """
        return self._website

    @website.setter
    def website(self, website):
        """Sets the website of this Repository.


        :param website: The website of this Repository.  # noqa: E501
        :type: str
        """

        self._website = website

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Repository, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Repository):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Repository):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.15.10+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from dcs_catalog_client.api.misc_api import MiscApi
from dcs_catalog_client.api.v3_api import V3Api
from dcs_catalog_client.api.v4_api import V4Api
from dcs_catalog_client.api.v5_api import V5Api

# import ApiClient
from dcs_catalog_client.api_client import ApiClient
from dcs_catalog_client.configuration import Configuration
# import models into sdk package
from dcs_catalog_client.models.access_token import AccessToken
from dcs_catalog_client.models.attachment import Attachment
from dcs_catalog_client.models.catalog_search_results_pivoted_v3 import CatalogSearchResultsPivotedV3
from dcs_catalog_client.models.catalog_search_results_v3 import CatalogSearchResultsV3
from dcs_catalog_client.models.catalog_search_results_v4 import CatalogSearchResultsV4
from dcs_catalog_client.models.catalog_search_results_v5 import CatalogSearchResultsV5
from dcs_catalog_client.models.catalog_stage import CatalogStage
from dcs_catalog_client.models.catalog_stages import CatalogStages
from dcs_catalog_client.models.catalog_v3 import CatalogV3
from dcs_catalog_client.models.catalog_v3_language import CatalogV3Language
from dcs_catalog_client.models.catalog_v3_pivoted import CatalogV3Pivoted
from dcs_catalog_client.models.catalog_v3_resource import CatalogV3Resource
from dcs_catalog_client.models.catalog_v3_subject import CatalogV3Subject
from dcs_catalog_client.models.catalog_v4 import CatalogV4
from dcs_catalog_client.models.catalog_v5 import CatalogV5
from dcs_catalog_client.models.catalog_version_endpoints import CatalogVersionEndpoints
from dcs_catalog_client.models.catalog_version_endpoints_response import CatalogVersionEndpointsResponse
from dcs_catalog_client.models.external_tracker import ExternalTracker
from dcs_catalog_client.models.external_wiki import ExternalWiki
from dcs_catalog_client.models.internal_tracker import InternalTracker
from dcs_catalog_client.models.o_auth2_application import OAuth2Application
from dcs_catalog_client.models.permission import Permission
from dcs_catalog_client.models.release import Release
from dcs_catalog_client.models.repository import Repository
from dcs_catalog_client.models.user import User



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.15.10+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class Release(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'assets': 'list[Attachment]',
        'author': 'User',
        'body': 'str',
        'created_at': 'datetime',
        'draft': 'bool',
        'html_url': 'str',
        'id': 'int',
        'name': 'str',
        'prerelease': 'bool',
        'published_at': 'datetime',
        'tag_name': 'str',
        'tarball_url': 'str',
        'target_commitish': 'str',
        'url': 'str',
        'zipball_url': 'str'
    }

    attribute_map = {
        'assets': 'assets',
        'author': 'author',
        'body': 'body',
        'created_at': 'created_at',
        'draft': 'draft',
        'html_url': 'html_url',
        'id': 'id',
        'name': 'name',
        'prerelease': 'prerelease',
        'published_at': 'published_at',
        'tag_name': 'tag_name',
        'tarball_url': 'tarball_url',
        'target_commitish': 'target_commitish',
        'url': 'url',
        'zipball_url': 'zipball_url'
    }

    def __init__(self, assets=None, author=None, body=None, created_at=None, draft=None, html_url=None, id=None, name=None, prerelease=None, published_at=None, tag_name=None, tarball_url=None, target_commitish=None, url=None, zipball_url=None, _configuration=None):  # noqa: E501
        """Release - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._assets = None
        self._author = None
        self._body = None
        self._created_at = None
        self._draft = None
        self._html_url = None
        self._id = None
        self._name = None
        self._prerelease = None
        self._published_at = None
        self._tag_name = None
        self._tarball_url = None
        self._target_commitish = None
        self._url = None
        self._zipball_url = None
        self.discriminator = None

        if assets is not None:
            self.assets = assets
        if author is not None:
            self.author = author
        if body is not None:
            self.body = body
        if created_at is not None:
            self.created_at = created_at
        if draft is not None:
            self.draft = draft
        if html_url is not None:
            self.html_url = html_url
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if prerelease is not None:
            self.prerelease = prerelease
        if published_at is not None:
            self.published_at = published_at
        if tag_name is not None:
            self.tag_name = tag_name
        if tarball_url is not None:
            self.tarball_url = tarball_url
        if target_commitish is not None:
            self.target_commitish = target_commitish
        if url is not None:
            self.url = url
        if zipball_url is not None:
            self.zipball_url = zipball_url

    @property
    def assets(self):
        """Gets the assets of this Release.  # noqa: E501


        :return: The assets of this Release.  # noqa: E501
        :rtype: list[Attachment]
        """
        return self._assets

    @assets.setter
    def assets(self, assets):
        """Sets the assets of this Release.


        :param assets: The assets of this Release.  # noqa: E501
        :type: list[Attachment]
        """

        self._assets = assets

    @property
    def author(self):
        """Gets the author of this Release.  # noqa: E501


        :return: The author of this Release.  # noqa: E501
        :rtype: User
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this Release.


        :param author: The author of this Release.  # noqa: E501
        :type: User
        """

        self._author = author

    @property
    def body(self):
        """Gets the body of this Release.  # noqa: E501


        :return: The body of this Release.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this Release.


        :param body: The body of this Release.  # noqa: E501
        :type: str
        """

        self._body = body

    @property
    def created_at(self):
        """Gets the created_at of this Release.  # noqa: E501


        :return: The created_at of this Release.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Release.


        :param created_at: The created_at of this Release.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def draft(self):
        """Gets the draft of this Release.  # noqa: E501


        :return: The draft of this Release.  # noqa: E501
        :rtype: bool
        """
        return self._draft

    @draft.setter
    def draft(self, draft):
        """Sets the draft of this Release.


        :param draft: The draft of this Release.  # noqa: E501
        :type: bool
        """

        self._draft = draft

    @property
    def html_url(self):
        """Gets the html_url of this Release.  # noqa: E501


        :return: The html_url of this Release.  # noqa: E501
        :rtype: str
        """
        return self._html_url

    @html_url.setter
    def html_url(self, html_url):
        """Sets the html_url of this Release.


        :param html_url: The html_url of this Release.  # noqa: E501
        :type: str
        """

        self._html_url = html_url

    @property
    def id(self):
        """Gets the id of this Release.  # noqa: E501


        :return: The id of this Release.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Release.


        :param id: The id of this Release.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Release.  # noqa: E501


        :return: The name of this Release.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Release.


        :param name: The name of this Release.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def prerelease(self):
        """Gets the prerelease of this Release.  # noqa: E501


        :return: The prerelease of this Release.  # noqa: E501
        :rtype: bool
        """
        return self._prerelease

    @prerelease.setter
    def prerelease(self, prerelease):
        """Sets the prerelease of this Release.


        :param prerelease: The prerelease of this Release.  # noqa: E501
        :type: bool
        """

        self._prerelease = prerelease

    @property
    def published_at(self):
        """Gets the published_at of this Release.  # noqa: E501


        :return: The published_at of this Release.  # noqa: E501
        :rtype: datetime
        """
        return self._published_at

    @published_at.setter
    def published_at(self, published_at):
        """Sets the published_at of this Release.


        :param published_at: The published_at of this Release.  # noqa: E501
        :type: datetime
        """

        self._published_at = published_at

    @property
    def tag_name(self):
        """Gets the tag_name of this Release.  # noqa: E501


        :return: The tag_name of this Release.  # noqa: E501
        :rtype: str
        """
        return self._tag_name

    @tag_name.setter
    def tag_name(self, tag_name):
        """Sets the tag_name of this Release.


        :param tag_name: The tag_name of this Release.  # noqa: E501
        :type: str
        """

        self._tag_name = tag_name

    @property
    def tarball_url(self):
        """Gets the tarball_url of this Release.  # noqa: E501


        :return: The tarball_url of this Release.  # noqa: E501
        :rtype: str
        """
        return self._tarball_url

    @tarball_url.setter
    def tarball_url(self, tarball_url):
        """Sets the tarball_url of this Release.


        :param tarball_url: The tarball_url of this Release.  # noqa: E501
        :type: str
        """

        self._tarball_url = tarball_url

    @property
    def target_commitish(self):
        """Gets the target_commitish of this Release.  # noqa: E501


        :return: The target_commitish of this Release.  # noqa: E501
        :rtype: str
        """
        return self._target_commitish

    @target_commitish.setter
    def target_commitish(self, target_commitish):
        """Sets the target_commitish of this Release.


        :param target_commitish: The target_commitish of this Release.  # noqa: E501
        :type: str
        """

        self._target_commitish = target_commitish

    @property
    def url(self):
        """Gets the url of this Release.  # noqa: E501


        :return: The url of this Release.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Release.


        :param url: The url of this Release.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def zipball_url(self):
        """Gets the zipball_url of this Release.  # noqa: E501


        :return: The zipball_url of this Release.  # noqa: E501
        :rtype: str
        """
        return self._zipball_url

    @zipball_url.setter
    def zipball_url(self, zipball_url):
        """Sets the zipball_url of this Release.


        :param zipball_url: The zipball_url of this Release.  # noqa: E501
        :type: str
        """

        self._zipball_url = zipball_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Release, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Release):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Release):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.15.10+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class InternalTracker(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allow_only_contributors_to_track_time': 'bool',
        'enable_issue_dependencies': 'bool',
        'enable_time_tracker': 'bool'
    }

    attribute_map = {
        'allow_only_contributors_to_track_time': 'allow_only_contributors_to_track_time',
        'enable_issue_dependencies': 'enable_issue_dependencies',
        'enable_time_tracker': 'enable_time_tracker'
    }

    def __init__(self, allow_only_contributors_to_track_time=None, enable_issue_dependencies=None, enable_time_tracker=None, _configuration=None):  # noqa: E501
        """InternalTracker - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._allow_only_contributors_to_track_time = None
        self._enable_issue_dependencies = None
        self._enable_time_tracker = None
        self.discriminator = None

        if allow_only_contributors_to_track_time is not None:
            self.allow_only_contributors_to_track_time = allow_only_contributors_to_track_time
        if enable_issue_dependencies is not None:
            self.enable_issue_dependencies = enable_issue_dependencies
        if enable_time_tracker is not None:
            self.enable_time_tracker = enable_time_tracker

    @property
    def allow_only_contributors_to_track_time(self):
        """Gets the allow_only_contributors_to_track_time of this InternalTracker.  # noqa: E501

        Let only contributors track time (Built-in issue tracker)  # noqa: E501

        :return: The allow_only_contributors_to_track_time of this InternalTracker.  # noqa: E501
        :rtype: bool
        """
        return self._allow_only_contributors_to_track_time

    @allow_only_contributors_to_track_time.setter
    def allow_only_contributors_to_track_time(self, allow_only_contributors_to_track_time):
        """Sets the allow_only_contributors_to_track_time of this InternalTracker.

        Let only contributors track time (Built-in issue tracker)  # noqa: E501

        :param allow_only_contributors_to_track_time: The allow_only_contributors_to_track_time of this InternalTracker.  # noqa: E501
        :type: bool
        """

        self._allow_only_contributors_to_track_time = allow_only_contributors_to_track_time

    @property
    def enable_issue_dependencies(self):
        """Gets the enable_issue_dependencies of this InternalTracker.  # noqa: E501

        Enable dependencies for issues and pull requests (Built-in issue tracker)  # noqa: E501

        :return: The enable_issue_dependencies of this InternalTracker.  # noqa: E501
        :rtype: bool
        """
        return self._enable_issue_dependencies

    @enable_issue_dependencies.setter
    def enable_issue_dependencies(self, enable_issue_dependencies):
        """Sets the enable_issue_dependencies of this InternalTracker.

        Enable dependencies for issues and pull requests (Built-in issue tracker)  # noqa: E501

        :param enable_issue_dependencies: The enable_issue_dependencies of this InternalTracker.  # noqa: E501
        :type: bool
        """

        self._enable_issue_dependencies = enable_issue_dependencies

    @property
    def enable_time_tracker(self):
        """Gets the enable_time_tracker of this InternalTracker.  # noqa: E501

        Enable time tracking (Built-in issue tracker)  # noqa: E501

        :return: The enable_time_tracker of this InternalTracker.  # noqa: E501
        :rtype: bool
        """
        return self._enable_time_tracker

    @enable_time_tracker.setter
    def enable_time_tracker(self, enable_time_tracker):
        """Sets the enable_time_tracker of this InternalTracker.

        Enable time tracking (Built-in issue tracker)  # noqa: E501

        :param enable_time_tracker: The enable_time_tracker of this InternalTracker.  # noqa: E501
        :type: bool
        """

        self._enable_time_tracker = enable_time_tracker

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InternalTracker, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InternalTracker):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InternalTracker):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.15.10+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class CatalogV3Resource(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'checking': 'dict(str, object)',
        'comment': 'str',
        'contributor': 'list[object]',
        'creator': 'str',
        'description': 'str',
        'formats': 'list[dict(str, object)]',
        'identifier': 'str',
        'issued': 'datetime',
        'modified': 'datetime',
        'owner': 'str',
        'projects': 'list[object]',
        'publisher': 'str',
        'relation': 'list[object]',
        'repo': 'str',
        'rights': 'str',
        'source': 'list[object]',
        'subject': 'str',
        'title': 'str',
        'version': 'str'
    }

    attribute_map = {
        'checking': 'checking',
        'comment': 'comment',
        'contributor': 'contributor',
        'creator': 'creator',
        'description': 'description',
        'formats': 'formats',
        'identifier': 'identifier',
        'issued': 'issued',
        'modified': 'modified',
        'owner': 'owner',
        'projects': 'projects',
        'publisher': 'publisher',
        'relation': 'relation',
        'repo': 'repo',
        'rights': 'rights',
        'source': 'source',
        'subject': 'subject',
        'title': 'title',
        'version': 'version'
    }

    def __init__(self, checking=None, comment=None, contributor=None, creator=None, description=None, formats=None, identifier=None, issued=None, modified=None, owner=None, projects=None, publisher=None, relation=None, repo=None, rights=None, source=None, subject=None, title=None, version=None, _configuration=None):  # noqa: E501
        """CatalogV3Resource - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._checking = None
        self._comment = None
        self._contributor = None
        self._creator = None
        self._description = None
        self._formats = None
        self._identifier = None
        self._issued = None
        self._modified = None
        self._owner = None
        self._projects = None
        self._publisher = None
        self._relation = None
        self._repo = None
        self._rights = None
        self._source = None
        self._subject = None
        self._title = None
        self._version = None
        self.discriminator = None

        if checking is not None:
            self.checking = checking
        if comment is not None:
            self.comment = comment
        if contributor is not None:
            self.contributor = contributor
        if creator is not None:
            self.creator = creator
        if description is not None:
            self.description = description
        if formats is not None:
            self.formats = formats
        if identifier is not None:
            self.identifier = identifier
        if issued is not None:
            self.issued = issued
        if modified is not None:
            self.modified = modified
        if owner is not None:
            self.owner = owner
        if projects is not None:
            self.projects = projects
        if publisher is not None:
            self.publisher = publisher
        if relation is not None:
            self.relation = relation
        if repo is not None:
            self.repo = repo
        if rights is not None:
            self.rights = rights
        if source is not None:
            self.source = source
        if subject is not None:
            self.subject = subject
        if title is not None:
            self.title = title
        if version is not None:
            self.version = version

    @property
    def checking(self):
        """Gets the checking of this CatalogV3Resource.  # noqa: E501


        :return: The checking of this CatalogV3Resource.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._checking

    @checking.setter
    def checking(self, checking):
        """Sets the checking of this CatalogV3Resource.


        :param checking: The checking of this CatalogV3Resource.  # noqa: E501
        :type: dict(str, object)
        """

        self._checking = checking

    @property
    def comment(self):
        """Gets the comment of this CatalogV3Resource.  # noqa: E501


        :return: The comment of this CatalogV3Resource.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this CatalogV3Resource.


        :param comment: The comment of this CatalogV3Resource.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def contributor(self):
        """Gets the contributor of this CatalogV3Resource.  # noqa: E501


        :return: The contributor of this CatalogV3Resource.  # noqa: E501
        :rtype: list[object]
        """
        return self._contributor

    @contributor.setter
    def contributor(self, contributor):
        """Sets the contributor of this CatalogV3Resource.


        :param contributor: The contributor of this CatalogV3Resource.  # noqa: E501
        :type: list[object]
        """

        self._contributor = contributor

    @property
    def creator(self):
        """Gets the creator of this CatalogV3Resource.  # noqa: E501


        :return: The creator of this CatalogV3Resource.  # noqa: E501
        :rtype: str
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this CatalogV3Resource.


        :param creator: The creator of this CatalogV3Resource.  # noqa: E501
        :type: str
        """

        self._creator = creator

    @property
    def description(self):
        """Gets the description of this CatalogV3Resource.  # noqa: E501


        :return: The description of this CatalogV3Resource.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CatalogV3Resource.


        :param description: The description of this CatalogV3Resource.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def formats(self):
        """Gets the formats of this CatalogV3Resource.  # noqa: E501


        :return: The formats of this CatalogV3Resource.  # noqa: E501
        :rtype: list[dict(str, object)]
        """
        return self._formats

    @formats.setter
    def formats(self, formats):
        """Sets the formats of this CatalogV3Resource.


        :param formats: The formats of this CatalogV3Resource.  # noqa: E501
        :type: list[dict(str, object)]
        """

        self._formats = formats

    @property
    def identifier(self):
        """Gets the identifier of this CatalogV3Resource.  # noqa: E501


        :return: The identifier of this CatalogV3Resource.  # noqa: E501
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """Sets the identifier of this CatalogV3Resource.


        :param identifier: The identifier of this CatalogV3Resource.  # noqa: E501
        :type: str
        """

        self._identifier = identifier

    @property
    def issued(self):
        """Gets the issued of this CatalogV3Resource.  # noqa: E501


        :return: The issued of this CatalogV3Resource.  # noqa: E501
        :rtype: datetime
        """
        return self._issued

    @issued.setter
    def issued(self, issued):
        """Sets the issued of this CatalogV3Resource.


        :param issued: The issued of this CatalogV3Resource.  # noqa: E501
        :type: datetime
        """

        self._issued = issued

    @property
    def modified(self):
        """Gets the modified of this CatalogV3Resource.  # noqa: E501


        :return: The modified of this CatalogV3Resource.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this CatalogV3Resource.


        :param modified: The modified of this CatalogV3Resource.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def owner(self):
        """Gets the owner of this CatalogV3Resource.  # noqa: E501


        :return: The owner of this CatalogV3Resource.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this CatalogV3Resource.


        :param owner: The owner of this CatalogV3Resource.  # noqa: E501
        :type: str
        """

        self._owner = owner

    @property
    def projects(self):
        """Gets the projects of this CatalogV3Resource.  # noqa: E501


        :return: The projects of this CatalogV3Resource.  # noqa: E501
        :rtype: list[object]
        """
        return self._projects

    @projects.setter
    def projects(self, projects):
        """Sets the projects of this CatalogV3Resource.


        :param projects: The projects of this CatalogV3Resource.  # noqa: E501
        :type: list[object]
        """

        self._projects = projects

    @property
    def publisher(self):
        """Gets the publisher of this CatalogV3Resource.  # noqa: E501


        :return: The publisher of this CatalogV3Resource.  # noqa: E501
        :rtype: str
        """
        return self._publisher

    @publisher.setter
    def publisher(self, publisher):
        """Sets the publisher of this CatalogV3Resource.


        :param publisher: The publisher of this CatalogV3Resource.  # noqa: E501
        :type: str
        """

        self._publisher = publisher

    @property
    def relation(self):
        """Gets the relation of this CatalogV3Resource.  # noqa: E501


        :return: The relation of this CatalogV3Resource.  # noqa: E501
        :rtype: list[object]
        """
        return self._relation

    @relation.setter
    def relation(self, relation):
        """Sets the relation of this CatalogV3Resource.


        :param relation: The relation of this CatalogV3Resource.  # noqa: E501
        :type: list[object]
        """

        self._relation = relation

    @property
    def repo(self):
        """Gets the repo of this CatalogV3Resource.  # noqa: E501


        :return: The repo of this CatalogV3Resource.  # noqa: E501
        :rtype: str
        """
        return self._repo

    @repo.setter
    def repo(self, repo):
        """Sets the repo of this CatalogV3Resource.


        :param repo: The repo of this CatalogV3Resource.  # noqa: E501
        :type: str
        """

        self._repo = repo

    @property
    def rights(self):
        """Gets the rights of this CatalogV3Resource.  # noqa: E501


        :return: The rights of this CatalogV3Resource.  # noqa: E501
        :rtype: str
        """
        return self._rights

    @rights.setter
    def rights(self, rights):
        """Sets the rights of this CatalogV3Resource.


        :param rights: The rights of this CatalogV3Resource.  # noqa: E501
        :type: str
        """

        self._rights = rights

    @property
    def source(self):
        """Gets the source of this CatalogV3Resource.  # noqa: E501


        :return: The source of this CatalogV3Resource.  # noqa: E501
        :rtype: list[object]
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this CatalogV3Resource.


        :param source: The source of this CatalogV3Resource.  # noqa: E501
        :type: list[object]
        """

        self._source = source

    @property
    def subject(self):
        """Gets the subject of this CatalogV3Resource.  # noqa: E501


        :return: The subject of this CatalogV3Resource.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this CatalogV3Resource.


        :param subject: The subject of this CatalogV3Resource.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def title(self):
        """Gets the title of this CatalogV3Resource.  # noqa: E501


        :return: The title of this CatalogV3Resource.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this CatalogV3Resource.


        :param title: The title of this CatalogV3Resource.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def version(self):
        """Gets the version of this CatalogV3Resource.  # noqa: E501


        :return: The version of this CatalogV3Resource.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this CatalogV3Resource.


        :param version: The version of this CatalogV3Resource.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CatalogV3Resource, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CatalogV3Resource):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CatalogV3Resource):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Catalog Next API.

    This documentation describes the Catalog Next API for all versions and other miscellaneous endpoints.  # noqa: E501

    OpenAPI spec version: 1.15.10+dcs
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from dcs_catalog_client.configuration import Configuration


class AccessToken(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'sha1': 'str',
        'token_last_eight': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'sha1': 'sha1',
        'token_last_eight': 'token_last_eight'
    }

    def __init__(self, id=None, name=None, sha1=None, token_last_eight=None, _configuration=None):  # noqa: E501
        """AccessToken - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._sha1 = None
        self._token_last_eight = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if sha1 is not None:
            self.sha1 = sha1
        if token_last_eight is not None:
            self.token_last_eight = token_last_eight

    @property
    def id(self):
        """Gets the id of this AccessToken.  # noqa: E501


        :return: The id of this AccessToken.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AccessToken.


        :param id: The id of this AccessToken.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this AccessToken.  # noqa: E501


        :return: The name of this AccessToken.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AccessToken.


        :param name: The name of this AccessToken.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def sha1(self):
        """Gets the sha1 of this AccessToken.  # noqa: E501


        :return: The sha1 of this AccessToken.  # noqa: E501
        :rtype: str
        """
        return self._sha1

    @sha1.setter
    def sha1(self, sha1):
        """Sets the sha1 of this AccessToken.


        :param sha1: The sha1 of this AccessToken.  # noqa: E501
        :type: str
        """

        self._sha1 = sha1

    @property
    def token_last_eight(self):
        """Gets the token_last_eight of this AccessToken.  # noqa: E501


        :return: The token_last_eight of this AccessToken.  # noqa: E501
        :rtype: str
        """
        return self._token_last_eight

    @token_last_eight.setter
    def token_last_eight(self, token_last_eight):
        """Sets the token_last_eight of this AccessToken.


        :param token_last_eight: The token_last_eight of this AccessToken.  # noqa: E501
        :type: str
        """

        self._token_last_eight = token_last_eight

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AccessToken, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccessToken):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccessToken):
            return True

        return self.to_dict() != other.to_dict()
